@@ -145,6 +145,11 @@ pub const LIBSSH2_SFTP_RENAME_NATIVE: c_long = 0x4;
 
 pub const LIBSSH2_INIT_NO_CRYPTO: c_int = 0x1;
 
+pub const LIBSSH2_SFTP_S_IFMT: c_ulong = 0o170000;
+pub const LIBSSH2_SFTP_S_IFDIR: c_ulong = 0o040000;
+pub const LIBSSH2_SFTP_S_IFREG: c_ulong = 0o100000;
+pub const LIBSSH2_SFTP_S_IFLNK: c_ulong = 0o120000;
+
 pub enum LIBSSH2_SESSION {}
 pub enum LIBSSH2_AGENT {}
 pub enum LIBSSH2_CHANNEL {}
@@ -528,4 +533,25 @@ fn smoke() {
     unsafe { libssh2_init(0) };
 }
 
+#[doc(hidden)]
 pub fn issue_14344_workaround() {}
+
+pub fn init() {
+    use std::sync::{Once, ONCE_INIT};
+
+    static INIT: Once = ONCE_INIT;
+    INIT.call_once(|| unsafe {
+        platform_init();
+        assert_eq!(libssh2_init(LIBSSH2_INIT_NO_CRYPTO), 0);
+        assert_eq!(libc::atexit(shutdown), 0);
+    });
+    extern fn shutdown() { unsafe { libssh2_exit(); } }
+
+    #[cfg(unix)]
+    fn platform_init() {
+        openssl_sys::init();
+    }
+
+    #[cfg(windows)]
+    fn platform_init() {}
+}
